==> lordsawar_0.1.0.orig.tar.gz: lordsawar-0.1.0/src/gui/surrender-dialog.cpp <==
//  Copyright (C) 2007, 2008 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#include <config.h>

#include <libglademm/xml.h>
#include <gtkmm/eventbox.h>
#include <sigc++/functors/mem_fun.h>
#include <gtkmm/label.h>

#include "surrender-dialog.h"

#include "glade-helpers.h"
#include "image-helpers.h"
#include "input-helpers.h"
#include "../ucompose.hpp"
#include "../defs.h"
#include "../File.h"

SurrenderDialog::SurrenderDialog(int numEnemies)
{
    Glib::RefPtr<Gnome::Glade::Xml> xml
	= Gnome::Glade::Xml::create(get_glade_path()
				    + "/surrender-dialog.glade");

    Gtk::Dialog *d = 0;
    xml->get_widget("dialog", d);
    dialog.reset(d);

    Gtk::Label *label;
    xml->get_widget("label", label);
    xml->get_widget("image", image);
    
    Glib::ustring s;
    s = String::ucompose
      (ngettext("Your final opponent comes on bended knee and offers surrender!",
		"%1 opponents come on bended knee and offer surrender!",
		numEnemies), numEnemies);
    s += _("\nDo you accept?");
    label->set_text(s);
    image->property_file()
      = File::getMiscFile("various/parley_offered.png");
}


void SurrenderDialog::set_parent_window(Gtk::Window &parent)
{
  dialog->set_transient_for(parent);
  //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
}

void SurrenderDialog::hide()
{
  dialog->hide();
}
bool SurrenderDialog::run()
{
  return dialog->run();
}

==> lordsawar_0.1.5.orig.tar.gz: lordsawar-0.1.5/src/gui/surrender-dialog.cpp <==
//  Copyright (C) 2007, 2008 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#include <config.h>

#include <libglademm/xml.h>
#include <gtkmm/eventbox.h>
#include <sigc++/functors/mem_fun.h>
#include <gtkmm/label.h>

#include "surrender-dialog.h"

#include "glade-helpers.h"
#include "image-helpers.h"
#include "input-helpers.h"
#include "ucompose.hpp"
#include "defs.h"
#include "File.h"

SurrenderDialog::SurrenderDialog(int numEnemies)
{
    Glib::RefPtr<Gnome::Glade::Xml> xml
	= Gnome::Glade::Xml::create(get_glade_path()
				    + "/surrender-dialog.glade");

    Gtk::Dialog *d = 0;
    xml->get_widget("dialog", d);
    dialog.reset(d);
    decorate(dialog.get());
    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));

    Gtk::Label *label;
    xml->get_widget("label", label);
    xml->get_widget("image", image);
    
    Glib::ustring s;
    s = String::ucompose
      (ngettext("Your final opponent comes on bended knee and offers surrender!",
		"%1 opponents come on bended knee and offer surrender!",
		numEnemies), numEnemies);
    s += _("\nDo you accept?");
    label->set_text(s);
    image->property_file()
      = File::getMiscFile("various/parley_offered.png");
}


void SurrenderDialog::set_parent_window(Gtk::Window &parent)
{
  dialog->set_transient_for(parent);
  //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
}

void SurrenderDialog::hide()
{
  dialog->hide();
}
bool SurrenderDialog::run()
{
  return dialog->run();
}
